Blob Blame History Raw
diff -upr python-caja-1.4.0-orig/src/caja-python.c python-caja-1.4.0/src/caja-python.c
--- python-caja-1.4.0-orig/src/caja-python.c	2012-07-11 19:00:19.000000000 +0200
+++ python-caja-1.4.0/src/caja-python.c	2014-04-05 10:13:45.013700924 +0200
@@ -363,7 +363,15 @@ caja_module_initialize(GTypeModule *modu
 
 	all_types = g_array_new(FALSE, FALSE, sizeof(GType));
 
-	// Look in the new global path, $DATADIR/caja-python/extensions
+	// Look in the new global path, $DATADIR/python-caja/extensions
+	caja_python_load_dir(module, DATADIR "/python-caja/extensions");
+
+	// Look in new XDG_DATA_DIR, ~/.local/share/python-caja/extensions
+	user_extensions_dir = g_build_filename(g_get_user_data_dir(), 
+		"caja-python", "extensions", NULL);
+	caja_python_load_dir(module, user_extensions_dir);
+
+	// Look in the global path, $DATADIR/caja-python/extensions
 	caja_python_load_dir(module, DATADIR "/caja-python/extensions");
 
 	// Look in XDG_DATA_DIR, ~/.local/share/caja-python/extensions